==========
smecv_grid
==========

.. image:: https://travis-ci.org/TUW-GEO/smecv-grid.svg?branch=master
    :target: https://travis-ci.org/TUW-GEO/smecv-grid

.. image:: https://coveralls.io/repos/github/TUW-GEO/smecv-grid/badge.svg?branch=master
    :target: https://coveralls.io/github/TUW-GEO/smecv-grid?branch=master

.. image:: https://readthedocs.org/projects/smecv-grid/badge/?version=latest
    :target: http://smecv-grid.readthedocs.io/en/latest/?badge=latest

.. image:: https://badge.fury.io/py/smecv-grid.svg
    :target: https://badge.fury.io/py/smecv-grid

Grid definition of the Discrete Global Grid (DGG) used for the creation of the CCI soil moisture products and
the Copernicus Climate Change Service products.


Description
===========

The DGG is a regular 0.25 degree grid utilizing cell partitioning.


Note
====

This project has been set up using PyScaffold 2.5.11. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
